function [ Awoo ] = WoodruffLowRankApprox( obj )
%WOODRUFFLOWRANKAPPROX Single-View Low-Rank Approximation by Woodruff
%This function implements the method [25, Thm.4.3, display 1] proposed by 
%Woodruff, which takes the form (4.9) from the main reference [TYUC2017]. 
%(4.9) is algebraically equivalent to (4.3). In floating-point arithmetic, 
%our approximation (4.3) implemented in Algorithms 3 and 4 is superior.
%   Ensure:  Returns the low rank reconstrution Awoo of the sketched
%            matrix.
%
%   Awoo = S.WoodruffLowRankApprox() returns the rank-q approximation
%   of the target matrix A for some q <= k. This implements Woodruff's
%   low rank approximation formulation (4.9) in [TYUC2017]. This is
%   algebraically the same as Algorithms 3 and 4.
%
%See our reference paper for the detailed explanation of the sketching
%procedure and the arithmetic, communication and storage costs.
%
%[TYUC2017] J.A. Tropp, A. Yurtsever, M. Udell and V. Cevher, Practical  
%Sketching Algorithms for Low-Rank Matrix Approximation, SIMAX, 2017
%
%[Woo2014] D.P. Woodruff, Sketching as a Tool for Numerical Linear Algebra,
%Found. Trends Theor. Comput. Sci. 10 (2014)
%
%Coded by: Alp Yurtsever
%Ecole Polytechnique Federale de Lausanne, Switzerland.
%Laboratory for Information and Inference Systems, LIONS.
%contact: alp.yurtsever@epfl.ch
%Created: July 05, 2016
%Last modified: January 13, 2017
%
%PRACTICALSKETCHING-v1.0
%Copyright (C) 2017 Laboratory for Information and Inference Systems
%(LIONS), Ecole Polytechnique Federale de Lausanne, Switzerland.
%
%This code is a part of PRACTICALSKETCHING toolbox.
%Please read COPYRIGHT before using this file.

% Awoo = obj.Y*pinv(obj.Psi*obj.Y)*obj.W;
Awoo = obj.Y*((obj.Psi*obj.Y)\obj.W);

end

