%PRACTICALSKETCHING-v1.0
%Copyright (C) 2017 Laboratory for Information and Inference Systems
%(LIONS), Ecole Polytechnique Federale de Lausanne, Switzerland.
%
%This code is a part of PRACTICALSKETCHING toolbox. 
%Please read COPYRIGHT before using this file.
% 
%This script draws a single random examplar for the input matrix classes 
%   (Low-Rank + no noise)
%   (Low-Rank + medium noise)
%   (Low-Rank + high noise)
%See Section 7.2.1 in [TYUC2017] for more details.
%
%   [TYUC2017] J.A. Tropp, A. Yurtsever, M. Udell and V. Cevher, Practical  
%   Sketching Algorithms for Low-Rank Matrix Approximation, SIMAX, 2017.
%
%   Coded by: Alp Yurtsever
%   Ecole Polytechnique Federale de Lausanne, Switzerland.
%   Laboratory for Information and Inference Systems, LIONS.
%   contact: alp.yurtsever@epfl.ch
%   Created: August 24, 2016
%   Last modified: August 25, 2017

%% Fix the seed
rng(0,'twister');

%% Test setup
clearvars

% gamma^(-2) can be interpreted as SNR
gamma = [0,0.01,1];
sname = {'NoNoise','MedNoise','HiNoise'};

% problem dimensions
n = 1000;
% rank of the "significant part"
R = 10;

for t = 1:length(gamma)
    
    % Generate the matrix A
    A = zeros(n,n);
    A(1:R,1:R) = diag(ones(R,1));
    G = (randn(n,n) + 1i*randn(n,n));
    A = A + (sqrt(gamma(t)*R/(2*n^2))).*(G+G');
    clearvars G;
    
    %% Find the ground truth (best rank-r approximation)
    [~, Sigmar, ~] = svd(A);
    singVals = diag(Sigmar);
    
    %% Save data
    dataname = ['data/LowRankPlusNoise_',sname{t},'_n',num2str(n),'_R',num2str(R),'.mat'];
    save(dataname)
    
end