%PRACTICALSKETCHING-v1.0
%Copyright (C) 2017 Laboratory for Information and Inference Systems
%(LIONS), Ecole Polytechnique Federale de Lausanne, Switzerland.
%
%This code is a part of PRACTICALSKETCHING toolbox. 
%Please read COPYRIGHT before using this file.
% 
%This script batches the experimental instances into the cluster.
%Experiments are carried out in parallel. 
%
%   [TYUC2017] J.A. Tropp, A. Yurtsever, M. Udell and V. Cevher, Practical  
%   Sketching Algorithms for Low-Rank Matrix Approximation, SIMAX, 2017.
%
%   Coded by: Alp Yurtsever
%   Ecole Polytechnique Federale de Lausanne, Switzerland.
%   Laboratory for Information and Inference Systems, LIONS.
%   contact: alp.yurtsever@epfl.ch
%   Created: December 31, 2016
%   Last modified: August 26, 2017

%% Beginning of the test

% problem specifications
n = 1000;
field = 'complex';
% target rank
r = 5;
% number of MonteCarlo simulations
MonteCarloNum = 20;

c = parcluster;

ClusterInfo.setMemUsage('4gb'); 

experiment          = {};
% Low-Rank + noise
experiment{end+1}   = @() Test_parfor_LowRankPlusNoise(n,r,10,'HiNoise',field,MonteCarloNum);
experiment{end+1}   = @() Test_parfor_LowRankPlusNoise(n,r,10,'MedNoise',field,MonteCarloNum);
experiment{end+1}   = @() Test_parfor_LowRankPlusNoise(n,r,10,'NoNoise',field,MonteCarloNum);
% Low-Rank + poly decay
experiment{end+1}   = @() Test_parfor_LowRankPlusPolyDecay(n,r,10,1,field,MonteCarloNum);
experiment{end+1}   = @() Test_parfor_LowRankPlusPolyDecay(n,r,10,2,field,MonteCarloNum);
% % Low-Rank + exp decay
experiment{end+1}   = @() Test_parfor_LowRankPlusExpDecay(n,r,10,1,field,MonteCarloNum);
experiment{end+1}   = @() Test_parfor_LowRankPlusExpDecay(n,r,10,0.25,field,MonteCarloNum);
% Real Data
experiment{end+1}   = @() Test_parfor_RealData(r,field,MonteCarloNum);
experiment{end+1}   = @() Test_parfor_RealData(1,field,MonteCarloNum);

j = {};
for tt = 1:length(experiment)
    fprintf('Batching experiment No:%d...',tt);
    c.batch(experiment{tt},1,{},'pool',MonteCarloNum,...
        'CurrentFolder','/home/yurtseve/Codes/PRACTICALSKETCHING');   % CURRENT FOLDER NEEDS TO BE CHANGED ACCORDINGLY!
    fprintf(' Started..\n');
end
