%PRACTICALSKETCHING-v1.0
%Copyright (C) 2017 Laboratory for Information and Inference Systems
%(LIONS), Ecole Polytechnique Federale de Lausanne, Switzerland.
%
%This code is a part of PRACTICALSKETCHING toolbox. 
%Please read COPYRIGHT before using this file.
% 
%   This script plots the Fig. 7.1 in [TYUC2017].
%
%   [TYUC2017] J.A. Tropp, A. Yurtsever, M. Udell and V. Cevher, Practical  
%   Sketching Algorithms for Low-Rank Matrix Approximation, SIMAX, 2017.
%
%   Coded by: Alp Yurtsever
%   Ecole Polytechnique Federale de Lausanne, Switzerland.
%   Laboratory for Information and Inference Systems, LIONS.
%   contact: alp.yurtsever@epfl.ch
%   Created: January 01, 2017
%   Last modified: August 25, 2017

%% LOAD DATA
clearvars
close all

hfig = {};
name = {};

%%
load data/LowRankPlusNoise_NoNoise_n1000_R10
singVal_NoNoise = singVals;
load data/LowRankPlusNoise_MedNoise_n1000_R10
singVal_MedNoise = singVals;
load data/LowRankPlusNoise_HiNoise_n1000_R10
singVal_HighNoise = singVals;

name{end+1} = 'LowRankPlusNoise';
hfig{end+1} = figure('Position',[100,100,350,320]);
set(hfig{end},'name',name{end},'numbertitle','off');
loglog(singVal_NoNoise,'-');
hold on
loglog(singVal_MedNoise,'--');
loglog(singVal_HighNoise,'-.');

set(gca,'TickDir','out')
set(gca,'LineWidth',1,'TickLength',[0.02 0.02]);
set(findall(gca, 'Type', 'Line'),'LineWidth',2); % set all lines width to 2

ylim([.7e-5,2])

ax = gca;
ax.YTick = 10.^[-10:10];

hleg = legend('LowRank', 'LowRankMed', 'LowRankHigh');
hleg.FontSize = 16;
hleg.Interpreter = 'latex';
hleg.Location = 'SouthEast';

set(ax, 'FontSize', 13)
xlabel('$j$','Interpreter','latex','FontSize',17);
ylabel('$j^{th}$ singular value','Interpreter','latex','FontSize',19);

ax1 = gca;

%%
name{end+1} = 'DecayingSpectrum';
hfig{end+1} = figure('Position',[100,100,350,320]);
set(hfig{end},'name',name{end},'numbertitle','off');
R = 10;

Sigma(1:R) = 1;
Sigma((R+1):n) = (((1:(n-R))+1).^(-1));
singVals_PSLOW = Sigma;
clearvars Sigma

Sigma(1:R) = 1;
Sigma((R+1):n) = (((1:(n-R))+1).^(-2));
singVals_PFAST = Sigma;
clearvars Sigma

Sigma(1:R) = 1;
Sigma((R+1):n) = 10.^(-0.25*((1:(n-R))+1));
singVals_ESLOW = Sigma;
clearvars Sigma

Sigma(1:R) = 1;
Sigma((R+1):n) = 10.^(-1*((1:(n-R))+1));
singVals_EFAST = Sigma;
clearvars Sigma

loglog(singVals_PSLOW,'-');
hold on
loglog(singVals_PFAST,'--');
loglog(singVals_ESLOW,'-.');
loglog(singVals_EFAST,':');

set(gca,'TickDir','out')
set(gca,'LineWidth',1,'TickLength',[0.02 0.02]);
set(findall(gca, 'Type', 'Line'),'LineWidth',2); % set all lines width to 2

hleg = legend('PolySlow', 'PolyFast', 'ExpSlow', 'ExpFast');
hleg.FontSize = 16;
hleg.Interpreter = 'latex';
hleg.Position = [0.608    0.658    0.276    0.258];
ylim([.7e-5,2])

ax = gca;
ax.YTick = 10.^[-10:1:10];

set(ax, 'FontSize', 13)
xlabel('$j$','Interpreter','latex','FontSize',17);
%ylabel('$j^{th}$ singular value','Interpreter','latex','FontSize',19);

ax.Position = ax1.Position;

%%
name{end+1} = 'RealData';
load data/FourrierPtychographySingVals
singVals_DATA = diag(info.Z);
singVals_DATA = singVals_DATA./max(singVals_DATA);

hfig{end+1} = figure('Position',[100,100,350,320]);
set(hfig{end},'name',name{end},'numbertitle','off');
loglog(singVals_DATA,'-');

set(gca,'TickDir','out')
set(gca,'LineWidth',1,'TickLength',[0.02 0.02]);
set(findall(gca, 'Type', 'Line'),'LineWidth',2); % set all lines width to 2

hleg = legend('Data');
hleg.FontSize = 16;
hleg.Interpreter = 'latex';
hleg.Location = 'NorthEast';

ax = gca;
ax.YTick = 10.^[-30:3:30];

set(ax, 'FontSize', 13)
xlabel('$j$','Interpreter','latex','FontSize',17);
%ylabel('$j^{th}$ singular value','Interpreter','latex','FontSize',19);

ax.Position = ax1.Position;


