%PRACTICALSKETCHING-v1.0
%Copyright (C) 2017 Laboratory for Information and Inference Systems
%(LIONS), Ecole Polytechnique Federale de Lausanne, Switzerland.
%
%This code is a part of PRACTICALSKETCHING toolbox. 
%Please read COPYRIGHT before using this file.
% 
%   This script plots the Fig. 7.2 in [TYUC2017].
%
%   [TYUC2017] J.A. Tropp, A. Yurtsever, M. Udell and V. Cevher, Practical  
%   Sketching Algorithms for Low-Rank Matrix Approximation, SIMAX, 2017.
%
%   Coded by: Alp Yurtsever
%   Ecole Polytechnique Federale de Lausanne, Switzerland.
%   Laboratory for Information and Inference Systems, LIONS.
%   contact: alp.yurtsever@epfl.ch
%   Created: January 01, 2017
%   Last modified: August 27, 2017

%% LOAD DATA
clearvars
close all
hfig = {};

experiment = {};
experimentName = {};
isylabel = {};


%% Low-Rank + noise

experiment{end+1}       = 'Test_parfor_LowRankPlusNoise/NoNoise_n1000_r5_R10_complex/';
experimentName{end+1}   = 'LR';
isylabel{end+1}         = 1;

experiment{end+1}       = 'Test_parfor_LowRankPlusNoise/MedNoise_n1000_r5_R10_complex/';
experimentName{end+1}   = 'MED';
isylabel{end+1}         = 0;

experiment{end+1}       = 'Test_parfor_LowRankPlusNoise/HiNoise_n1000_r5_R10_complex/';
experimentName{end+1}   = 'HI';
isylabel{end+1}         = 0;

%% Low-Rank + poly decay

experiment{end+1}       = 'Test_parfor_LowRankPlusPolyDecay/n1000_r5_R10_p1_complex/';
experimentName{end+1}   = 'PSLOW';
isylabel{end+1}         = 1;

experiment{end+1}       = 'Test_parfor_LowRankPlusPolyDecay/n1000_r5_R10_p2_complex/';
experimentName{end+1}   = 'PFAST';
isylabel{end+1}         = 0;

%% Low-Rank + exp decay

experiment{end+1}       = 'Test_parfor_LowRankPlusExpDecay/n1000_r5_R10_q0.25_complex/';
experimentName{end+1}   = 'ESLOW';
isylabel{end+1}         = 0;

experiment{end+1}       = 'Test_parfor_LowRankPlusExpDecay/n1000_r5_R10_q1_complex/';
experimentName{end+1}   = 'EFAST';
isylabel{end+1}         = 1;

%% Real Data
experiment{end+1}       = 'Test_parfor_RealData/r1_complex/';
experimentName{end+1}   = 'DATA1';
isylabel{end+1}         = 0;

experiment{end+1}       = 'Test_parfor_RealData/r5_complex/';
experimentName{end+1}   = 'DATA5';
isylabel{end+1}         = 0;

%% Colors and more
cAlg7   = [0,0,0];
cWoo    = [1,0,0];
cCemmp  = [0,0,1];
cUpd    = [0,.5,0];

%% First test: Test_parfor_IdentityMatrix
for rr = 1:length(experiment)
    clearvars Err*
    dname = dir(['results/',experiment{rr},'*.mat']);
    load(['results/',experiment{rr},dname.name]);
    
    numMonteCarlo = length(MCresults);
    numDataPoint  = length(MCresults{1}.info.T);
    
    % below, MCresults{1}.info.T is the fixed sum T=k+l
    kl = MCresults{1}.info.T;
    r = MCresults{1}.info.r;
    
    for ll = 1:numMonteCarlo
        for tt = 1:numDataPoint
            ErrA7FroMin(ll,tt)     = abs(min(MCresults{ll}.ErrA7Fro{tt})     /   MCresults{ll}.ErrBestFro     -   1); % minimum over all (k,l) pairs
            %ErrA8FroMin(ll,tt)     = min(MCresults{ll}.ErrA8Fro{tt})     /   MCresults{ll}.ErrBestFro     -   1; % minimum over all (k,l) pairs
            %ErrA9FroMin(ll,tt)     = min(MCresults{ll}.ErrA9Fro{tt})     /   MCresults{ll}.ErrBestFro     -   1; % minimum over all (k,l) pairs
            ErrWooFroMin(ll,tt)    = min(MCresults{ll}.ErrWooFro{tt})    /   MCresults{ll}.ErrBestFro     -   1; % minimum over all (k,l) pairs
            ErrCemmpFroMin(ll,tt)  = min(MCresults{ll}.ErrCemmpFro{tt})  /   MCresults{ll}.ErrBestFro     -   1; % minimum over all (k,l) pairs
            ErrBwzFroMin(ll,tt)    = min(MCresults{ll}.ErrBwzFro{tt})    /   MCresults{ll}.ErrBestFro     -   1; % minimum over all (k,l) pairs
        end
    end
    
    % Compute average relative error over all Monte Carlo iterations
    ErrA7FroMin = mean(ErrA7FroMin,1);
    %ErrA8FroMin = mean(ErrA8FroMin,1);
    %ErrA9FroMin = mean(ErrA9FroMin,1);
    ErrWooFroMin = mean(ErrWooFroMin,1);
    ErrCemmpFroMin = mean(ErrCemmpFroMin,1);
    ErrBwzFroMin = mean(ErrBwzFroMin,1);

    hfig{rr} = figure('Position',[100,100,350,320]);
    set(hfig{rr},'name',experimentName{rr},'numbertitle','off')
    loglog(MCresults{1}.info.T, ErrWooFroMin,':', 'Marker', 'o','Color',cWoo)
    hold on
    loglog(MCresults{1}.info.T, ErrCemmpFroMin,':', 'Marker', '^','Color',cCemmp)
    loglog(MCresults{1}.info.T, ErrBwzFroMin,':', 'Marker', 'd','Color',cUpd)
    loglog(MCresults{1}.info.T, ErrA7FroMin,':', 'Marker', '+','Color',cAlg7)

    if rr == length(experiment)
    hleg = legend(...
        'Woo (7.2)', ...
        'Cemmp (7.3)', ...
        'Bwz (7.6)', ...
        'Algorithm 7' ...
        );
    hleg.FontSize = 16;
    hleg.Interpreter = 'latex';
    hleg.Location = 'SouthWest';
    end
    
    ax = gca;
    ax.XTick = MCresults{1}.info.T(2) * 2.^(0:10);
    set(ax, 'FontSize', 13)
    xlabel('$T$','Interpreter','latex','FontSize',17);
    if isylabel{rr}
    ylabel('relative error','Interpreter','latex','FontSize',19);
    end
    
    axis tight
    xlim([-inf, inf])
    ylimCur = ylim;
    ylimCur(1) = max(ylimCur(1),1e-10);
    ylim(ylimCur);
    set(gca,'TickDir','out')
    set(gca,'LineWidth',1,'TickLength',[0.02 0.02]);
    set(findall(gca, 'Type', 'Line'),'LineWidth',2); % set all lines width to 2
    set(findall(gca, 'Type', 'Line'),'LineStyle',':'); % set all lines to dotdots
    set(findall(gca, 'Type', 'Line'),'MarkerSize',11); % set all lines width to 2
    set(findall(gca, 'Type', 'Line'),'MarkerFaceColor','auto'); % set all lines width to 2
    
    if rr == 1
        setPos = ax.Position;
    else
        ax.Position = setPos;
    end
    
end



