%PRACTICALSKETCHING-v1.0
%Copyright (C) 2017 Laboratory for Information and Inference Systems
%(LIONS), Ecole Polytechnique Federale de Lausanne, Switzerland.
%
%This code is a part of PRACTICALSKETCHING toolbox. 
%Please read COPYRIGHT before using this file.
% 
%   This script plots the Fig. 7.4 in [TYUC2017].
%
%   [TYUC2017] J.A. Tropp, A. Yurtsever, M. Udell and V. Cevher, Practical  
%   Sketching Algorithms for Low-Rank Matrix Approximation, SIMAX, 2017.
%
%   Coded by: Alp Yurtsever
%   Ecole Polytechnique Federale de Lausanne, Switzerland.
%   Laboratory for Information and Inference Systems, LIONS.
%   contact: alp.yurtsever@epfl.ch
%   Created: January 01, 2017
%   Last modified: January 02, 2017

%% LOAD DATA
clearvars
close all
hfig = {};

experiment = {};
experimentName          = {};
isylabel         = {};

%% Low-Rank + noise

experiment{end+1}       = 'Test_parfor_LowRankPlusNoise/MedNoise_n1000_r5_R10_complex/';
experimentName{end+1}   = 'MED';
isylabel{end+1}         = 1;

experiment{end+1}       = 'Test_parfor_LowRankPlusNoise/HiNoise_n1000_r5_R10_complex/';
experimentName{end+1}   = 'HI';
isylabel{end+1}         = 0;

%% Low-Rank + poly decay

experiment{end+1}       = 'Test_parfor_LowRankPlusPolyDecay/n1000_r5_R10_p1_complex/';
experimentName{end+1}   = 'PSLOW';
isylabel{end+1}         = 1;

experiment{end+1}       = 'Test_parfor_LowRankPlusPolyDecay/n1000_r5_R10_p2_complex/';
experimentName{end+1}   = 'PFAST';
isylabel{end+1}         = 0;

%% Low-Rank + exp decay

experiment{end+1}       = 'Test_parfor_LowRankPlusExpDecay/n1000_r5_R10_q0.25_complex/';
experimentName{end+1}   = 'ESLOW';
isylabel{end+1}         = 0;

experiment{end+1}       = 'Test_parfor_LowRankPlusExpDecay/n1000_r5_R10_q1_complex/';
experimentName{end+1}   = 'EFAST';
isylabel{end+1}         = 1;

%% Real Data
experiment{end+1}       = 'Test_parfor_RealData/r1_complex/';
experimentName{end+1}   = 'DATA1';
isylabel{end+1}         = 0;

experiment{end+1}       = 'Test_parfor_RealData/r5_complex/';
experimentName{end+1}   = 'DATA5';
isylabel{end+1}         = 0;

%% Colors and more
cOracle  = [0.5,0.5,0.5];
cFlat    = [1,0,0];
cDecay   = [0,0,1];
cRapid   = [0,.5,0];

%% First test: Test_parfor_IdentityMatrix
for rr = 1:length(experiment)
    clearvars Err*
    dname = dir(['results/',experiment{rr},'*.mat']);
    load(['results/',experiment{rr},dname.name]);
    
    numMonteCarlo = length(MCresults);
    numDataPoint  = length(MCresults{1}.info.T);
    
    % below, MCresults{1}.info.T is the fixed sum T=k+l
    T = MCresults{1}.info.T;
    r = MCresults{1}.info.r;
    if strcmp(MCresults{1}.info.field,'real')
        alpha = 1;
    elseif strcmp(MCresults{1}.info.field,'complex')
        alpha = 0;
    end
    
    k_basic  = (2*r + alpha).*ones(size(T));
    if alpha == 1
        k_flat = max((r+alpha+1).*ones(size(T)), floor((T-1)*((sqrt(r*(T-r-2).*(1-2./(T-1)))-(r-1))./(T-2*r-1))));
    else
        k_flat   = max((r+alpha+1).*ones(size(T)), floor(T.*((sqrt(r*(T-r))-r)./(T-2*r))));
    end
    k_decay  = max((r+alpha+1).*ones(size(T)), floor((T-alpha)/3));
    k_rapid  = floor((T-alpha-1)/2);
    
    for ll = 1:numMonteCarlo
        for tt = 1:numDataPoint
            ErrA7FroMin(ll,tt)     = abs(min(MCresults{ll}.ErrA7Fro{tt})     /   MCresults{ll}.ErrBestFro     -   1); % minimum over all (k,l) pairs
            ind_basic = find(MCresults{ll}.k{tt} == k_basic(tt)); % Index of theoretical (k,l) pair
            ind_flat  = find(MCresults{ll}.k{tt} == k_flat(tt)); % Index of theoretical (k,l) pair
            ind_decay = find(MCresults{ll}.k{tt} == k_decay(tt)); % Index of theoretical (k,l) pair
            ind_rapid = find(MCresults{ll}.k{tt} == k_rapid(tt)); % Index of theoretical (k,l) pair
            if isempty(ind_basic), ind_basic = 1; end
            ErrA7FroBasic(ll,tt)    = abs(MCresults{ll}.ErrA7Fro{tt}(ind_basic)    /   MCresults{ll}.ErrBestFro     -   1); % minimum over all (k,l) pairs
            if isempty(ind_flat), ind_flat = 1; end
            ErrA7FroFlat(ll,tt)     = abs(MCresults{ll}.ErrA7Fro{tt}(ind_flat)     /   MCresults{ll}.ErrBestFro     -   1); % minimum over all (k,l) pairs
            if isempty(ind_decay), ind_decay = 1; end
            ErrA7FroDecay(ll,tt)    = abs(MCresults{ll}.ErrA7Fro{tt}(ind_decay)    /   MCresults{ll}.ErrBestFro     -   1); % minimum over all (k,l) pairs
            if isempty(ind_rapid), ind_rapid = 1; end
            ErrA7FroRapid(ll,tt)    = abs(MCresults{ll}.ErrA7Fro{tt}(ind_rapid)    /   MCresults{ll}.ErrBestFro     -   1); % minimum over all (k,l) pairs
        end
    end
    
    % Compute average relative error over all Monte Carlo iterations
    ErrA7FroMin  = mean(ErrA7FroMin,1);
    ErrA7FroBasic = mean(ErrA7FroBasic,1);
    ErrA7FroFlat  = mean(ErrA7FroFlat,1);
    ErrA7FroDecay = mean(ErrA7FroDecay,1);
    ErrA7FroRapid = mean(ErrA7FroRapid,1);
    
    hfig{rr} = figure('Position',[100,100,350,320]);

    set(hfig{rr},'name',experimentName{rr},'numbertitle','off')
    %loglog(MCresults{1}.info.T, ErrA7FroBasic, 'Marker', '^')
    loglog(MCresults{1}.info.T, ErrA7FroMin, 'Color',cOracle)
    hold on
    loglog(MCresults{1}.info.T, ErrA7FroFlat, 'Marker', 's',  'Color',cFlat,'LineStyle',':')
    loglog(MCresults{1}.info.T, ErrA7FroDecay, 'Marker', '+',  'Color',cDecay,'LineStyle',':')
    loglog(MCresults{1}.info.T, ErrA7FroRapid, 'Marker', 'x',  'Color',cRapid,'LineStyle',':')
    if rr == length(experiment)
        hleg = legend(...  % 'Basic', ...
            'ORACLE', ...
            'FLAT', ...
            'DECAY', ...
            'RAPID' ...
            );
        hleg.FontSize = 16;
        hleg.Interpreter = 'latex';
        hleg.Location = 'SouthWest';
    end
    
    
    ax = gca;
    ax.XTick = MCresults{1}.info.T(2) * 2.^(0:10);
    set(ax, 'FontSize', 13)
    xlabel('$T$','Interpreter','latex','FontSize',17);
    if isylabel{rr}
        ylabel('relative error','Interpreter','latex','FontSize',19);
    end
    
    axis tight
    xlim([-inf, inf])
    ylimCur = ylim;
    ylimCur(1) = max(ylimCur(1),1e-10);
    ylim(ylimCur);
    set(gca,'TickDir','out')
    set(gca,'LineWidth',1,'TickLength',[0.02 0.02]);
    set(findall(gca, 'Type', 'Line'),'LineWidth',2); % set all lines width to 2
    set(findall(gca, 'Type', 'Line'),'MarkerSize',11); % set all lines width to 2
    set(findall(gca, 'Type', 'Line'),'MarkerFaceColor','auto'); % set all lines width to 2
    
    if rr == 1
        setPos = ax.Position;
    else
        ax.Position = setPos;
    end
end


