function [dummy] = Test_parfor_LowRankPlusNoise(n,r,R,noiseLevel,field,MonteCarloNum)
%This function runs Monte Carlo simulations in a parfor loop, with an input 
%matrix from the low rank plus noise class. See section 7.2.1 for the 
%details about input matrix.
%	Inputs: n 		-> size of input matrix (n x n)
%			r		-> target rank
%			R		-> Rank of "significant part"
%			noiseLevel	-> NO, MED, or HI noise level
% 			field 	-> field for the test matrices: 'complex' or 'real'
%           MonteCarloNum -> number of MonteCarlo simulations.
%	Output: Saves the results of the tests under "./results/" folder.
%
%   See our reference paper for the detailed explanation of the
%   sketching procedure and the arithmetic and storage costs.
%
%   [TYUC2017] J.A. Tropp, A. Yurtsever, M. Udell and V. Cevher, Practical  
%   Sketching Algorithms for Low-Rank Matrix Approximation, SIMAX, 2017.
%
%   Coded by: Alp Yurtsever
%   Ecole Polytechnique Federale de Lausanne, Switzerland.
%   Laboratory for Information and Inference Systems, LIONS.
%   contact: alp.yurtsever@epfl.ch
%   Created: December 31, 2016
%   Last modified: August 25, 2017
%
%PRACTICALSKETCHING-v1.0
%Copyright (C) 2017 Laboratory for Information and Inference Systems
%(LIONS), Ecole Polytechnique Federale de Lausanne, Switzerland.
%
%This code is a part of PRACTICALSKETCHING toolbox. 
%Please read COPYRIGHT before using this file.

%% Beginning of the test

MCresults = cell(MonteCarloNum,1);

parfor tt = 1:MonteCarloNum

    MCresults{tt} = Test_single_LowRankPlusNoise(n,r,R,noiseLevel,field);
end

name = [noiseLevel,'_n',num2str(n),'_r',num2str(r),'_R',num2str(R),'_',field,'/'];
savepath = ['results/',mfilename,'/',name];
if ~exist(savepath,'dir'), mkdir(savepath); end
filename = datestr(now,30);
save([savepath,filename],'-v7.3','MCresults');

dummy = 1;

end