function [sd] = Test_single_LowRankPlusExpDecay(n,r,R,q,field)
%This script runs an experimental instance using a matrix with exponential 
%decay in the spectrum. See section 7.2.1 for the details about input
%matrix.
%	Inputs: m 		-> size of input matrix (m x m)
%			r		-> target rank
%			R		-> Rank of "significant part"
%			q		-> parameter that controls the rate of decay
% 			field 	-> field for the test matrices: 'complex' or 'real'.
%	Output: sd		-> structure with following fields
%						* ErrBestFro 
%						* ErrBestSpect
%						* info
%						* ID
%						* k,l,t and s
%						* ErrA7Fro, ErrA8Fro, ErrA9Fro
%						* ErrWooFro, ErrCemmpFro, ErrUpaFro
%
%For different values of (T = k+l), we sweep over all possible (k,l) pairs,  
%and record the approximation error, norm(A - Aapprox,'fro'). 
%
%In addition to the algorithms we recommend, our numerical study comprises 
%other methods that have appeared in the literature. See Section 7.3 for  
%the details about these algorithms. 
%
%   See our reference paper for the detailed explanation of the
%   sketching procedure and the arithmetic and storage costs.
%
%   [TYUC2017] J.A. Tropp, A. Yurtsever, M. Udell and V. Cevher, Practical  
%   Sketching Algorithms for Low-Rank Matrix Approximation, SIMAX, 2017.
%
%   Coded by: Alp Yurtsever
%   Ecole Polytechnique Federale de Lausanne, Switzerland.
%   Laboratory for Information and Inference Systems, LIONS.
%   contact: alp.yurtsever@epfl.ch
%   Created: December 31, 2016
%   Last modified: August 26, 2017
%
%PRACTICALSKETCHING-v1.0
%Copyright (C) 2017 Laboratory for Information and Inference Systems
%(LIONS), Ecole Polytechnique Federale de Lausanne, Switzerland.
%
%This code is a part of PRACTICALSKETCHING toolbox. 
%Please read COPYRIGHT before using this file.


%% Create or load data
% Generate the matrix A
Sigma(1:R) = 1;
Sigma((R+1):n) = 10.^(-q*((1:(n-R))+1));
% Sigma = ((1:min(m,n)).^(-p)).';
A = diag(Sigma+0*1i);
% Find the ground truth (best rank-r approximation)
ErrBestFro = norm(Sigma(r+1:end));
ErrBestSpect = norm(Sigma(r+1:end),inf);

%% Run the generic test file
TestGeneric_kl_Type1();

end