function [sd] = Test_single_LowRankPlusNoise(n,r,R,noiseLevel,field)
%This script runs an experimental instance using a matrix from the low rank 
%plus noise class. See section 7.2.1 for the details about input matrix.
%	Inputs: r		-> target rank
%			data	-> data name: 'NoNoise'     (no noise) 
%								  'MediumNoise' (medium noise) 
%								  'HighNoise'   (high noise)
% 			field 	-> field for the test matrices: 'complex' or 'real'.
%	Output: sd		-> structure with following fields
%						* ErrBestFro 
%						* ErrBestSpect
%						* info
%						* ID
%						* k,l,t and s
%						* ErrA7Fro, ErrA8Fro, ErrA9Fro
%						* ErrWooFro, ErrCemmpFro, ErrUpaFro
%
%For different values of (T = k+l), we sweep over all possible (k,l) pairs,  
%and record the approximation error, norm(A - Aapprox,'fro'). 
%
%In addition to the algorithms we recommend, our numerical study comprises 
%other methods that have appeared in the literature. See Section 7.3 for  
%the details about these algorithms. 
%
%This script runs an experimental instance using a matrix whose spectrum
%has a polynomila decay. See Section 10.1.2. for more information about
%this class of matrix input.
%
%   See our reference paper for the detailed explanation of the
%   sketching procedure and the arithmetic and storage costs.
%
%   [TYUC2017] J.A. Tropp, A. Yurtsever, M. Udell and V. Cevher, Practical  
%   Sketching Algorithms for Low-Rank Matrix Approximation, SIMAX, 2017.
%
%   Coded by: Alp Yurtsever
%   Ecole Polytechnique Federale de Lausanne, Switzerland.
%   Laboratory for Information and Inference Systems, LIONS.
%   contact: alp.yurtsever@epfl.ch
%   Created: December 31, 2016
%   Last modified: August 25, 2017
%
%PRACTICALSKETCHING-v1.0
%Copyright (C) 2017 Laboratory for Information and Inference Systems
%(LIONS), Ecole Polytechnique Federale de Lausanne, Switzerland.
%
%This code is a part of PRACTICALSKETCHING toolbox. 
%Please read COPYRIGHT before using this file.



dataname = ['data/LowRankPlusNoise_',noiseLevel,'_n',num2str(n),'_R',num2str(R),'.mat'];

if ~exist(dataname,'file')
    error(['Data file not found: Before go to the data folder and run ' ... 
    '''CreateData.m'' file to generate a dataset for noisy low-rank' ...
    'model before running this script.']);
end
load(dataname)
ErrBestFro = norm(singVals(r+1:end));
ErrBestSpect = norm(singVals(r+1:end),inf);

%% Run the generic test file
TestGeneric_kl_Type1();

end