function [sd] = Test_single_RealData(r, field)
%This script runs an experimental instance using a complex psd matrix (DATA)
%obtained from a real-world phase retrieval application. See section 7.2.2
%for the details about input matrix.
%   Inputs: r		-> target rank
% 			field 	-> field for the test matrices: 'complex' or 'real'.
%	Output: sd		-> structure with following fields
%						* ErrBestFro 
%						* ErrBestSpect
%						* info
%						* ID
%						* k,l,t and s
%						* ErrA7Fro, ErrA8Fro, ErrA9Fro
%						* ErrWooFro, ErrCemmpFro, ErrUpaFro
%
%   See our reference paper for the detailed explanation of the
%   sketching procedure and the arithmetic and storage costs.
%
%   [TYUC2017] J.A. Tropp, A. Yurtsever, M. Udell and V. Cevher, Practical  
%   Sketching Algorithms for Low-Rank Matrix Approximation, SIMAX, 2017.
%
%   Coded by: Alp Yurtsever
%   Ecole Polytechnique Federale de Lausanne, Switzerland.
%   Laboratory for Information and Inference Systems, LIONS.
%   contact: alp.yurtsever@epfl.ch
%   Created: December 15, 2016
%   Last modified: August 25, 2017
%
%PRACTICALSKETCHING-v1.0
%Copyright (C) 2017 Laboratory for Information and Inference Systems
%(LIONS), Ecole Polytechnique Federale de Lausanne, Switzerland.
%
%This code is a part of PRACTICALSKETCHING toolbox. 
%Please read COPYRIGHT before using this file.

%% Add some utilities to the path
% We add 'updateThinSVD' function that computes the sum of two low-rank
% matrices directly using their singular value decompositions
addpath utils

%% Generate test setup and/or load data
load('data/FourrierPtychographyData.mat');
U = info.U;
Z = info.Z;
Z = Z./Z(1);
Zd = diag(Z);
n = info.n;
clearvars info

% Find best rank-r errors
ErrBestFro = norm(Zd((r+1):end));
ErrBestSpect = norm(Zd((r+1):end),inf);

%% Run the generic test file
TestGeneric_kl_Type2();

end
